summaryrefslogtreecommitdiffstats
path: root/chalk/ui/kis_tool.h
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/ui/kis_tool.h')
-rw-r--r--chalk/ui/kis_tool.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/chalk/ui/kis_tool.h b/chalk/ui/kis_tool.h
index cd9cc424..45f3fbd1 100644
--- a/chalk/ui/kis_tool.h
+++ b/chalk/ui/kis_tool.h
@@ -34,8 +34,8 @@ class TQEvent;
class TQKeyEvent;
class TQRect;
class TQWidget;
-class KActionCollection;
-class KRadioAction;
+class TDEActionCollection;
+class TDERadioAction;
class KDialog;
class KisBrush;
class KisGradient;
@@ -72,7 +72,7 @@ public:
virtual void paint(KisCanvasPainter& gc, const TQRect& rc) = 0;
/**
* This function is called after the creation of a tool to create the KAction corresponding
* to the tool.
*
* The code should look like :
@@ -80,7 +80,7 @@ public:
*
* @endcode
*/
- virtual void setup(KActionCollection *collection) = 0;
+ virtual void setup(TDEActionCollection *collection) = 0;
virtual void buttonPress(KisButtonPressEvent *e) = 0;
virtual void move(KisMoveEvent *e) = 0;
@@ -100,7 +100,7 @@ public:
* @return the current configuration widget.
*/
virtual TQWidget* optionWidget();
- KRadioAction *action() const { return m_action; }
+ TDERadioAction *action() const { return m_action; }
/**
* Return true if this tool wants auto canvas-scrolling to
@@ -131,7 +131,7 @@ private:
KisTool& operator=(const KisTool&);
protected:
- KRadioAction *m_action;
+ TDERadioAction *m_action;
bool m_ownAction;
private:
@@ -72,7 +72,7 @@ public:
virtual void paint(KisCanvasPainter& gc, const TQRect& rc) = 0;
/**
- * This function is called after the creation of a tool to create the KAction corresponding
+ * This function is called after the creation of a tool to create the TDEAction corresponding
* to the tool.
*